#' @keywords internal
"_PACKAGE"

## usethis namespace: start
#' @import rlang
#' @import vctrs
#' @importFrom glue glue
#' @importFrom glue glue_collapse
## usethis namespace: end
NULL

# Singletons
the <- new_environment()
